*Code for Thesis - Emilie C. Løberg, July 2020
*OECD Americas-edition: : This code is written with respect to the "Data_Industry_Americas.dta"-file
*Step-by-step procedure:

*1: Prepare Stata for time series analysis
tsset Time

*2 Obtain optimal lags for each variable (The SBIC is used as decsision criterium)
varsoc LNConsA 
varsoc LNGDPA
varsoc LNNGPA
varsoc LNOilPA

*3 Test for stationarity of each variable (ADF test and visual inspection of line plots )
*ADF test: (For lags: fill in the optimal lag for each of the variables from the previous step - 1, as you have to specify the number of lags for the process in first differences for dfuller. Base this on the results from the Step 2)
*Test for stationarity of the first difference if the first test showed not stationary.
*Perform the ADF test both with and without the presence of a trend.
dfuller LNConsA, lags (0)
dfuller LNGDPA, lags (0)
dfuller LNNGPA, lags (0)
dfuller LNOilPA, lags (0)

dfuller d.LNConsA, lags (0)
dfuller d.LNGDPA, lags (0)
dfuller d.LNNGPA, lags (0)
dfuller d.LNOilPA, lags (0)

dfuller LNConsA, trend lags (0)
dfuller LNGDPA, trend lags (0)
dfuller LNNGPA, trend lags (0)
dfuller LNOilPA, trend lags (0)

dfuller d.LNConsA, trend lags (0)
dfuller d.LNGDPA, trend lags (0)
dfuller d.LNNGPA, trend lags (0)
dfuller d.LNOilPA, trend lags (0)


*Plot line plots of the level and first difference of the various variables, to make a visual assessment of their stationarity. 
line LNConsA Time, ytitle("ln(Consumption of Natural Gas)") xtitle("Time [Year]") title(" ") subtitle(" ")
line LNGDPA Time, ytitle("ln(GDP)") xtitle("Time [Year]") title(" ") subtitle(" ")
line LNNGPA Time, ytitle("ln(Natural Gas Price)") xtitle("Time [Year]") title(" ") subtitle(" ")
line LNOilPA Time, ytitle("ln(Oil Price)") xtitle("Time [Year]") title(" ") subtitle(" ")

line d.LNConsA Time, ytitle("{&Delta}ln(Consumption of Natural Gas)") xtitle("Time [Year]") title(" ") subtitle(" ")
line d.LNGDPA Time, ytitle("{&Delta}ln(GDP)") xtitle("Time [Year]") title(" ") subtitle(" ")
line d.LNNGPA Time, ytitle("{&Delta}ln(Natural Gas Price)") xtitle("Time [Year]") title(" ") subtitle(" ")
line d.LNOilPA Time, ytitle("{&Delta}ln(Oil Price)") xtitle("Time [Year]") title(" ") subtitle(" ")

*4 Estimate the ARDL model
*Here a maximum-lag constraint is included.
*For the case in which ARDL( 1, 1, 1, 1)models are estimated "maxlags(1 1 1 1)" is replaced with "lags(1 1 1 1"
ardl LNConsA LNGDPA LNNGPA LNOilPA, maxlags(1 1 1 1)

*5 Perform bounds cointegration test
*First, run the regression using the ec-command, which estimates with the dependent variable in first difference-form and display output in error-correction form.
*Second, run the Pesaran, Shin & Smith (2001) bounds test to check if there is cointegration
*"estat ectest" calculates the test statistics and show the Kripfganz and Schneider (2018) finite sample bounds.
*"estat ectest, asymp" calculates the test statistics and show the Kripfganz and Schneider (2018) asymptotic bounds.
ardl LNConsA LNGDPA LNNGPA LNOilPA, maxlags(1 1 1 1) ec
estat ectest
estat ectest, asymp

*6 Perform diagnostic tests
// Alt 1: There is no cointegration
*6.1 Estimate only the ARDL-model like in Step 4
*7.1 Perform Diagnostics tests
*"regstore(reg") saves the estimates 
*"estimates restore reg" restores these estimates into a variable called "_est_reg" so that the command "regress" can be performed. By doing this it becomes possible to perform diagnostic tests on the estimates.
ardl LNConsA LNGDPA LNNGPA LNOilPA, maxlags(1 1 1 1) regstore(reg)
estimates restore reg
regress
   

*This test for serial correlation using the Breusch-Godfrey Lagrange Multiplier test for Autocorrelation (Godfrey, 1978)
*The amount of lags per variable is specified by "lags(1)".
estat bgodfrey, lags(1)

*These test for heteroskedasticity using the test for heteroskedasticity suggested by White (1980).
estat imtest, white 

*This tests for model misspecification through omitted variable bias, using the Ramsey(1969) RESET test 
ovtest

*The remaining tests requires the residuals of the ardl-model

*The following line creates a variable containing the residuals, called "uhat".
predict uhat,r

*This test checks for normally distributed residuals using the test suggested by D`Agostino et al. (1990) which tests jointly for skewness and kurtosis.
sktest uhat

*These two plots provide information on whether or not the residuals are normally distributed through visual inspection:
*qnorm is a Normal Quantile plot, also known as a Quantile Quantile plot
*pnorm is a Normal Probability plot
qnorm uhat, ytitle("Sample Quantiles") xtitle("Theoretical Quantiles") title(" ") subtitle(" ")
pnorm uhat, ytitle("Expected Cumulative Probability") xtitle("Observed Cumulative Probability") title(" ") subtitle(" ")

*This tests for the stability of the model using the Brown et al. (1975) CUSUM-test. A CUSUM plot with 95% confidence bounds is also generated.
estat sbcusum, ytitle("CUSUM") xtitle("Time [year]") title(" ") subtitle(" ")

// Alt. 2. There is cointegration
*6.2 In addition to the ARDL-model in Step 4, also estimate the error correction model 
ardl LNConsA LNGDPA LNNGPA LNOilPA, maxlags(1 1 1 1) ec

*7.2 Perform Diagnostics tests (Exactly the same as for Alt. 1)
*"regstore(reg") saves the estimates 
*"estimates restore reg" restores these estimates into a variable called "_est_reg" so that the command "regress" can be performed. By doing this it becomes possible to perform diagnostic tests on the estimates.
ardl LNConsA LNGDPA LNNGPA LNOilPA, maxlags(1 1 1 1) regstore(reg)
estimates restore reg
regress
   
*This test for serial correlation using the Breusch-Godfrey Lagrange Multiplier test for Autocorrelation (Godfrey, 1978)
*The amount of lags per variable is specified by "lags(1)".
estat bgodfrey, lags(1)

*These test for heteroskedasticity using the test for heteroskedasticity suggested by White (1980).
estat imtest, white 

*This tests for model misspecification through omitted variable bias, using the Ramsey(1969) RESET test 
ovtest

*The remaining tests requires the residuals of the ardl-model

*The following line creates a variable containing the residuals, called "uhat".
predict uhat,r

*This test checks for normally distributed residuals using the test suggested by D`Agostino et al. (1990) which tests jointly for skewness and kurtosis.
sktest uhat

*These two plots provide information on whether or not the residuals are normally distributed through visual inspection:
*qnorm is a Normal Quantile plot, also known as a Quantile Quantile plot
*pnorm is a Normal Probability plot

qnorm uhat, ytitle("Sample Quantiles") xtitle("Theoretical Quantiles") title(" ") subtitle(" ")
pnorm uhat, ytitle("Expected Cumulative Probability") xtitle("Observed Cumulative Probability") title(" ") subtitle(" ")

*This tests for the stability of the model using the Brown et al. (1975) CUSUM-test. A CUSUM plot with 95% confidence bounds is also generated.
estat sbcusum, ytitle("CUSUM") xtitle("Time [year]") title(" ") subtitle(" ")

